==> morla-0.7.tar.gz: morla-0.7/src/editor.h <==
/* morla - Copyright (C) 2005-2006 bakunin - Andrea Marchesini 
 *                                     <bakunin@somasuite.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <glib.h>
#include <glib/gstdio.h>

#include <gtk/gtk.h>

#include <nxml.h>

#include <libxslt/transform.h>
#include <libxslt/xsltutils.h>

#include <redland.h>
#include <libgtkhtml/gtkhtml.h>

#ifdef ENABLE_NLS
#  include <glib/gi18n-lib.h>
#endif

enum rdf_object_t
{
  RDF_OBJECT_BLANK,
  RDF_OBJECT_LITERAL,
  RDF_OBJECT_RESOURCE
};

enum order_t
{
  ORDER_SUBJECT,
  ORDER_SUBJECT_DEC,
  ORDER_PREDICATE,
  ORDER_PREDICATE_DEC,
  ORDER_OBJECT,
  ORDER_OBJECT_DEC
};

enum nsorder_t
{
  NSORDER_NAMESPACE,
  NSORDER_NAMESPACE_DEC,
  NSORDER_PREFIX,
  NSORDER_PREFIX_DEC,
  NSORDER_VISIBLE,
  NSORDER_VISIBLE_DEC
};

struct namespace_t
{
  gchar *namespace;
  GtkWidget *namespace_widget;

  gchar *prefix;
  GtkWidget *prefix_widget;

  gboolean visible;
  GtkWidget *visible_widget;
};

struct rdf_t
{
  gchar *subject;
  GtkWidget *subject_widget;

  gchar *predicate;
  GtkWidget *predicate_widget;

  gchar *object;
  GtkWidget *object_widget;

  enum rdf_object_t object_type;
  GtkWidget *object_type_widget;

  gchar *lang;
  GtkWidget *lang_widget;
};

struct rdfs_t
{
  gchar *resource;
  gchar *prefix;
  gchar *path;

  GList *data;
  GList *nsdata;
};

struct thread_t
{
  GFunc func;
  gpointer data;
  gint *flag;
};

struct graph_data_t
{
  gchar *color;
  gchar *fontcolor;
  gchar *style;
  gchar *fillcolor;
  gchar *shape;
  gchar *fontname;
  gint fontsize;
};

enum unredo_type_t
{
  UNREDO_TYPE_ADD,
  UNREDO_TYPE_DEL,
  UNREDO_TYPE_CHANGE
};

struct unredo_change_t
{
  struct rdf_t *now;
  struct rdf_t *prev;
};

struct unredo_t
{
  enum unredo_type_t type;
  GList *list;
};

struct info_box_t
{
  gchar *value;
  gchar *lang;
};

struct editor_data_t
{
  struct editor_data_t *next;

  gchar *file;
  gchar *uri;

  GList *rdf;
  GList *namespace;

  GList *undo;
  GList *redo;

  gint changed;

  GtkWidget *label;
  GtkWidget *maker;

  GtkWidget *list;
  GtkWidget *nslist;

  GtkWidget *subject_order;
  GtkWidget *predicate_order;
  GtkWidget *object_order;
  enum order_t compare;

  GtkWidget *namespace_order;
  GtkWidget *prefix_order;
  GtkWidget *visible_order;
  enum nsorder_t nscompare;

  gchar *node_select;
  gchar *node_nsselect;

  struct rdf_t *rdf_select;
};

struct template_t
{
  gchar *uri;
  gchar *name;
  gchar *version;
  gchar *category;
  GList *input;
};

enum template_input_typevalue_t
{
  TEMPLATE_INPUT_TYPEVALUE_NONE,
  TEMPLATE_INPUT_TYPEVALUE_RESOURCE,
  TEMPLATE_INPUT_TYPEVALUE_LITERAL,
  TEMPLATE_INPUT_TYPEVALUE_ALT_RESOURCE,
  TEMPLATE_INPUT_TYPEVALUE_ALT_LITERAL,
  TEMPLATE_INPUT_TYPEVALUE_OTHER
};

struct template_input_t
{
  GList *labels;
  GList *comments;

  gchar *rdfs;

  gint min_cardinality;
  gint max_cardinality;

  enum template_input_typevalue_t typevalue;
  GList *alt_typevalue;
  gchar *other_typevalue;

  gboolean visible;
  gchar *defaultvalue;
};

struct update_template_t
{
  gchar *uri;
  gchar *name;
  gchar *description;
  gchar *author;
  gchar *version;
};

struct update_t
{
  gchar *last_version;
  GList *templates;
};

#define LOCK	1
#define WAIT	2
#define UNLOCK	3

#define THIS_DOCUMENT	"this:document"
#define BLANK_NODE	"blank_node:"

#define RDF_TYPE	"http://www.w3.org/1999/02/22-rdf-syntax-ns#type"
#define RDF_ITEM	"http://www.w3.org/1999/02/22-rdf-syntax-ns#_"

#define RDF_PROPERTY	"http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
#define RDFS_LITERAL	"http://www.w3.org/2000/01/rdf-schema#Literal"
#define RDFS_RESOURCE	"http://www.w3.org/2000/01/rdf-schema#Resource"

#define RDFS_COMMENT	"http://www.w3.org/2000/01/rdf-schema#comment"
#define RDFS_LABEL	"http://www.w3.org/2000/01/rdf-schema#label"

#define RDFS_DOMAIN	"http://www.w3.org/2000/01/rdf-schema#domain"
#define RDFS_RANGE	"http://www.w3.org/2000/01/rdf-schema#range"

#define RDF_ALT		"http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt"
#define RDF_BAG		"http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag"
#define RDF_SEQ		"http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq"

#define OWL_O_PROPERTY	"http://www.w3.org/2002/07/owl#ObjectProperty"
#define OWL_DT_PROPERTY	"http://www.w3.org/2002/07/owl#DatatypeProperty"

#define MORLA_NS	"http://www.autistici.org/bakunin/morla/morla#"

#define MORLA_TEMPLATE	"http://www.autistici.org/bakunin/morla/morla#Template"
#define MORLA_INPUT	"http://www.autistici.org/bakunin/morla/morla#Input"

#define MORLA_HASINPUT	"http://www.autistici.org/bakunin/morla/morla#HasInput"
#define MORLA_HASVERSION \
		"http://www.autistici.org/bakunin/morla/morla#HasVersion"
#define MORLA_CATEGORY	"http://www.autistici.org/bakunin/morla/morla#Category"
#define MORLA_HASRDFS	"http://www.autistici.org/bakunin/morla/morla#HasRDFS"
#define MORLA_TYPEVALUE	"http://www.autistici.org/bakunin/morla/morla#TypeValue"
#define MORLA_MINCARD	\
	"http://www.autistici.org/bakunin/morla/morla#MinCardinality"
#define MORLA_MAXCARD	\
	"http://www.autistici.org/bakunin/morla/morla#MaxCardinality"
#define MORLA_VISIBLE	"http://www.autistici.org/bakunin/morla/morla#Visible"
#define MORLA_DEFAULTVALUE \
		"http://www.autistici.org/bakunin/morla/morla#DefaultValue"

#define UPDATE_URL	"http://www.autistici.org/bakunin/morla/update"
#define HELP_URL	"http://autistici.org/bakunin/morla/doc/"

#define MORLA_ALT_RESOURCE \
		"http://www.autistici.org/bakunin/morla/morla#AltResource"

#define MORLA_ALT_LITERAL \
		"http://www.autistici.org/bakunin/morla/morla#AltLiteral"

#define MORLA_WEBSITE \
		"http://www.autistici.org/bakunin/morla/"

#define UNDO_MAX_VALUE		10
#define LAST_DOCUMENT_VALUE	5

extern int editor_statusbar_lock;

extern struct editor_data_t *editor_data;
extern GtkWidget *notebook;

extern gchar *browser_default;
extern gchar *viewer_default;

extern GList *thread_child;
extern GList *rdfs_list;
extern gint last_id;

extern struct graph_data_t graph_blank_node;
extern struct graph_data_t graph_resource_node;
extern struct graph_data_t graph_literal_node;
extern struct graph_data_t graph_edge;
extern gchar *graph_format;

extern gchar *normal_bg_color;
extern gchar *prelight_bg_color;
extern gchar *normal_fg_color;
extern gchar *prelight_fg_color;

extern GList *template_list;

extern GtkWidget *template_menu;
extern GtkWidget *template_toolbar;

extern GList *last_list;
extern GtkWidget *last_menu;
extern gint last_document_value;

extern GtkWidget *undo_widget[2];
extern GtkWidget *redo_widget[2];
extern gint undo_max_value;

extern gint update_show;
extern gchar *update_url;

extern gchar *help_url;

/* edit.c */
void editor_add (GtkWidget *, gpointer);
void editor_cut (GtkWidget *, gpointer);
void editor_copy (GtkWidget *, gpointer);
void editor_paste (GtkWidget *, gpointer);
void editor_delete (GtkWidget *, gpointer);
void editor_cut_triple (GtkWidget *, gpointer);
void editor_copy_triple (GtkWidget *, gpointer);
void editor_delete_triple (GtkWidget *, gpointer);
struct rdf_t *editor_triple (struct rdf_t *prev, gchar * title);
void editor_merge_file (GtkWidget *, gpointer);
void editor_merge_uri (GtkWidget *, gpointer);

/* file.c */
gboolean editor_open_file (gchar *, gchar *);
gboolean editor_open_uri (gchar *);
void editor_open (GtkWidget *, gpointer);
void editor_save_as (GtkWidget *, gpointer);
void editor_save (GtkWidget *, gpointer);
void editor_close (GtkWidget *, gpointer);
void editor_new (GtkWidget *, gpointer);
gchar *editor_tmp_file (void);

/* main.c */
int editor_quit (GtkWidget *, GdkEvent *, gpointer);
gchar *utf8 (gchar * str);
char *markup (gchar * str);
void statusbar_set (gchar * what, ...);
void fatal (gchar * text, ...);
void run (gchar ** a, GChildWatchFunc, gpointer);
GList *split (gchar * ar);

/* maker.c */
struct editor_data_t *editor_get_data (void);
gint editor_timeout (gpointer);
void editor_new_maker (struct editor_data_t *data);
void editor_refresh (struct editor_data_t *);
void editor_refresh_nslist (struct editor_data_t *);
gint editor_compare (struct rdf_t *, struct rdf_t *, struct editor_data_t *);
gint editor_nscompare (struct namespace_t *, struct namespace_t *,
		       struct editor_data_t *);

/* edit.c */
void editor_view (GtkWidget *, gpointer);
void editor_your_view (GtkWidget *, gpointer);
void editor_preferences (GtkWidget *, gpointer);
GList * create_no_dup (GList * ret);
GList *create_resources (struct editor_data_t *data);
GList *create_resources_by_rdfs (GList * ret);
GList *create_blank (struct editor_data_t *data);
void search_resources (GtkWidget * widget, GtkWidget * entry);

/* dialog.c */
void dialog_msg (gchar *);
int dialog_ask (gchar *);
int dialog_ask_with_cancel (gchar *);
GtkWidget *dialog_wait (GCallback callback, gpointer data, GtkWidget ** pb);

/* filechooser.c */
void *file_chooser (gchar *, GtkSelectionMode, GtkFileChooserAction);
gchar *uri_chooser (gchar *);

/* rdf.c */
GList *rdf_parse (gchar * file, gboolean this_document);
int rdf_save_file (gchar * file, GList * rdf, GList ** namespace);
int rdf_is_no_saved (struct editor_data_t *data);
void rdf_free (struct rdf_t *);
struct rdf_t *rdf_copy (struct rdf_t *);
gboolean rdf_blank (GList * rdf, gchar * t);
gboolean rdf_resource (GList * rdf, gchar * t);
gboolean rdf_parse_thread (gchar * resource, GList ** list, GList ** nslist,
			   gboolean this_document);

/* namespace.c */
GList *namespace_parse (GList * rdf);
void namespace_free (struct namespace_t *);
gboolean namespace_visible (GList * ns, struct rdf_t *rdf);
gchar *namespace_prefix (GList ** ns, gchar * t);
gchar *namespace_create (GList *, gchar * t);

/* browser.c */
void browser (gchar *);
void browser_website (void);

/* init.c */
void init (void);
void init_save (void);

/* rdfs.c */
void rdfs (GtkWidget * w, gpointer dummy);
gint rdfs_add (gchar * resource, gchar * prefix);
gchar *rdfs_file (void);

/* graph.c */
void graph_run (GtkWidget * w, gpointer dummy);
void graph (struct editor_data_t *);
void graph_save (GtkWidget * w, gpointer dummy);
void graph_graphviz (void);

/* about.c */
void about (GtkWidget * w, gpointer dummy);

/* template.c */
void template_update (void);
void template_import_uri (GtkWidget * w, gpointer dummy);
void template_import_file (GtkWidget * w, gpointer dummy);
void template (GtkWidget * w, gpointer dummy);
gboolean template_import (gchar * uri, gboolean, gboolean);
void template_save (void);

/* preferences.c */
void preferences (void);

/* splash.c */
void splash_show (void);
void splash_hide (void);
gboolean splash_showed (void);
void splash_set_text (char *, ...);
void splash_set_text_with_effect (char *, ...);
void splash_sleep (int);
void splash_close_on_click (gboolean value);

/* unredo.c */
struct unredo_t *unredo_new (struct editor_data_t *, enum unredo_type_t);
void unredo_add (struct unredo_t *unredo, struct rdf_t *rdf, struct rdf_t *);
void unredo_destroy (struct editor_data_t *, struct unredo_t *);
void unredo_undo (void);
void unredo_redo (void);
void unredo_change_value (void);

/* update.c */
gint update_timer (void);
void update_search (void);
gint update_check (void);

/* merge.c */
GList *merge (GList * rdf, gchar * what);
void merge_graph (void);

/* navigator.c */
void navigator_run (void);
void navigator_open_uri (void);

/* search.c */
gboolean search (gchar * uri, GList ** meta, GList ** other, gchar ** error);
void search_open (gchar * text, void (*func) (gchar *, gpointer), gpointer);

/* last.c */
void last_update (void);
void last_add (gchar * uri);
void last_change_value (void);

/* help.c */
void help (void);

/* info.c */
gboolean info_box_popup_show(GtkWidget *, GdkEventButton *, GList *);
gboolean info_box_popup_hide(GtkWidget *, GdkEventButton *, gpointer);
gboolean info_box_enter (GtkWidget *, GdkEventCrossing * , gpointer);
gboolean info_box_leave (GtkWidget *, GdkEventCrossing *, gpointer);
void info_box_free(struct info_box_t *);

/* EOF */

==> morla-0.9.tar.gz: morla-0.9/src/editor.h <==
/* morla - Copyright (C) 2005-2006 bakunin - Andrea Marchesini 
 *                                     <bakunin@somasuite.org>
 *
 * This source code is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Public License as published 
 * by the Free Software Foundation; either version 2 of the License,
 * or (at your option) any later version.
 *
 * This source code is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * Please refer to the GNU Public License for more details.
 *
 * You should have received a copy of the GNU Public License along with
 * this source code; if not, write to:
 * Free Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 */

#include <glib.h>
#include <glib/gstdio.h>

#include <gtk/gtk.h>

#include <nxml.h>

#include <libxslt/transform.h>
#include <libxslt/xsltutils.h>

#include <redland.h>
#include <libgtkhtml/gtkhtml.h>

#ifdef ENABLE_NLS
#  include <glib/gi18n-lib.h>
#endif

enum rdf_object_t
{
  RDF_OBJECT_BLANK,
  RDF_OBJECT_LITERAL,
  RDF_OBJECT_RESOURCE
};

enum order_t
{
  ORDER_SUBJECT,
  ORDER_SUBJECT_DEC,
  ORDER_PREDICATE,
  ORDER_PREDICATE_DEC,
  ORDER_OBJECT,
  ORDER_OBJECT_DEC
};

enum nsorder_t
{
  NSORDER_NAMESPACE,
  NSORDER_NAMESPACE_DEC,
  NSORDER_PREFIX,
  NSORDER_PREFIX_DEC,
  NSORDER_VISIBLE,
  NSORDER_VISIBLE_DEC
};

struct namespace_t
{
  gchar *namespace;
  GtkWidget *namespace_widget;

  gchar *prefix;
  GtkWidget *prefix_widget;

  gboolean visible;
  GtkWidget *visible_widget;
};

enum rdf_format_t
{
  RDF_FORMAT_XML = 0,
  RDF_FORMAT_NTRIPLES,
  RDF_FORMAT_TURTLE
};

struct rdf_t
{
  gchar *subject;
  GtkWidget *subject_widget;

  gchar *predicate;
  GtkWidget *predicate_widget;

  gchar *object;
  GtkWidget *object_widget;

  enum rdf_object_t object_type;
  GtkWidget *object_type_widget;

  gchar *lang;
  GtkWidget *lang_widget;
};

struct rdfs_t
{
  gchar *resource;
  gchar *prefix;
  gchar *path;

  GList *data;
  GList *nsdata;
};

struct thread_t
{
  GFunc func;
  gpointer data;
  gint *flag;
};

struct graph_data_t
{
  gchar *color;
  gchar *fontcolor;
  gchar *style;
  gchar *fillcolor;
  gchar *shape;
  gchar *fontname;
  gint fontsize;
};

enum unredo_type_t
{
  UNREDO_TYPE_ADD,
  UNREDO_TYPE_DEL,
  UNREDO_TYPE_CHANGE
};

struct unredo_change_t
{
  struct rdf_t *now;
  struct rdf_t *prev;
};

struct unredo_t
{
  enum unredo_type_t type;
  GList *list;
};

struct info_box_t
{
  gchar *value;
  gchar *lang;
};

struct editor_data_t
{
  struct editor_data_t *next;

  gchar *file;
  gchar *uri;

  enum rdf_format_t format;

  GList *rdf;
  GList *namespace;

  GList *undo;
  GList *redo;

  gint changed;

  GtkWidget *label;
  GtkWidget *maker;

  GtkWidget *list;
  GtkWidget *nslist;

  GtkWidget *subject_order;
  GtkWidget *predicate_order;
  GtkWidget *object_order;
  enum order_t compare;

  GtkWidget *namespace_order;
  GtkWidget *prefix_order;
  GtkWidget *visible_order;
  enum nsorder_t nscompare;

  gchar *node_select;
  gchar *node_nsselect;

  struct rdf_t *rdf_select;
};

struct template_t
{
  gchar *uri;
  gchar *name;
  gchar *version;
  gchar *category;
  GList *input;
};

enum template_input_typevalue_t
{
  TEMPLATE_INPUT_TYPEVALUE_NONE,
  TEMPLATE_INPUT_TYPEVALUE_RESOURCE,
  TEMPLATE_INPUT_TYPEVALUE_LITERAL,
  TEMPLATE_INPUT_TYPEVALUE_ALT_RESOURCE,
  TEMPLATE_INPUT_TYPEVALUE_ALT_LITERAL,
  TEMPLATE_INPUT_TYPEVALUE_OTHER
};

struct template_input_t
{
  GList *labels;
  GList *comments;

  gchar *rdfs;

  gint min_cardinality;
  gint max_cardinality;

  enum template_input_typevalue_t typevalue;
  GList *alt_typevalue;
  gchar *other_typevalue;

  gboolean visible;
  gchar *defaultvalue;
};

struct update_template_t
{
  gchar *uri;
  gchar *name;
  gchar *description;
  gchar *author;
  gchar *version;
};

struct update_t
{
  gchar *last_version;
  GList *templates;
};

enum parser_char_t {
  PARSER_CHAR_INIT = '*',
  PARSER_CHAR_ERROR = '!',
  PARSER_CHAR_WARNING = '_'
};

#define LOCK	1
#define WAIT	2
#define UNLOCK	3

#define THIS_DOCUMENT	"this:document"
#define BLANK_NODE	"blank_node:"

#define RDF_TYPE	"http://www.w3.org/1999/02/22-rdf-syntax-ns#type"
#define RDF_ITEM	"http://www.w3.org/1999/02/22-rdf-syntax-ns#_"

#define RDF_PROPERTY	"http://www.w3.org/1999/02/22-rdf-syntax-ns#Property"
#define RDFS_LITERAL	"http://www.w3.org/2000/01/rdf-schema#Literal"
#define RDFS_RESOURCE	"http://www.w3.org/2000/01/rdf-schema#Resource"

#define RDFS_COMMENT	"http://www.w3.org/2000/01/rdf-schema#comment"
#define RDFS_LABEL	"http://www.w3.org/2000/01/rdf-schema#label"

#define RDFS_DOMAIN	"http://www.w3.org/2000/01/rdf-schema#domain"
#define RDFS_RANGE	"http://www.w3.org/2000/01/rdf-schema#range"

#define RDF_ALT		"http://www.w3.org/1999/02/22-rdf-syntax-ns#Alt"
#define RDF_BAG		"http://www.w3.org/1999/02/22-rdf-syntax-ns#Bag"
#define RDF_SEQ		"http://www.w3.org/1999/02/22-rdf-syntax-ns#Seq"

#define OWL_O_PROPERTY	"http://www.w3.org/2002/07/owl#ObjectProperty"
#define OWL_DT_PROPERTY	"http://www.w3.org/2002/07/owl#DatatypeProperty"

#define RDF_SUBCLASSOF	"http://www.w3.org/2000/01/rdf-schema#subClassOf"
#define RDF_SUBPROPERTYOF "http://www.w3.org/2000/01/rdf-schema#subPropertyOf"

#define MORLA_NS	"http://www.autistici.org/bakunin/morla/morla#"

#define MORLA_TEMPLATE	"http://www.autistici.org/bakunin/morla/morla#Template"
#define MORLA_INPUT	"http://www.autistici.org/bakunin/morla/morla#Input"

#define MORLA_HASINPUT	"http://www.autistici.org/bakunin/morla/morla#HasInput"
#define MORLA_HASVERSION \
		"http://www.autistici.org/bakunin/morla/morla#HasVersion"
#define MORLA_CATEGORY	"http://www.autistici.org/bakunin/morla/morla#Category"
#define MORLA_HASRDFS	"http://www.autistici.org/bakunin/morla/morla#HasRDFS"
#define MORLA_TYPEVALUE	"http://www.autistici.org/bakunin/morla/morla#TypeValue"
#define MORLA_MINCARD	\
	"http://www.autistici.org/bakunin/morla/morla#MinCardinality"
#define MORLA_MAXCARD	\
	"http://www.autistici.org/bakunin/morla/morla#MaxCardinality"
#define MORLA_VISIBLE	"http://www.autistici.org/bakunin/morla/morla#Visible"
#define MORLA_DEFAULTVALUE \
		"http://www.autistici.org/bakunin/morla/morla#DefaultValue"

#define UPDATE_URL	"http://www.autistici.org/bakunin/morla/update"
#define HELP_URL	"http://autistici.org/bakunin/morla/doc/"

#define MORLA_ALT_RESOURCE \
		"http://www.autistici.org/bakunin/morla/morla#AltResource"

#define MORLA_ALT_LITERAL \
		"http://www.autistici.org/bakunin/morla/morla#AltLiteral"

#define MORLA_WEBSITE \
		"http://www.autistici.org/bakunin/morla/"

#define UNDO_MAX_VALUE		10
#define LAST_DOCUMENT_VALUE	5

extern int editor_statusbar_lock;

extern struct editor_data_t *editor_data;
extern GtkWidget *notebook;

extern gchar *browser_default;
extern gchar *viewer_default;

extern GList *thread_child;
extern GList *rdfs_list;
extern gint last_id;

extern struct graph_data_t graph_blank_node;
extern struct graph_data_t graph_resource_node;
extern struct graph_data_t graph_literal_node;
extern struct graph_data_t graph_edge;
extern gchar *graph_format;

extern gchar *normal_bg_color;
extern gchar *prelight_bg_color;
extern gchar *normal_fg_color;
extern gchar *prelight_fg_color;

extern GList *template_list;

extern GList *template_menus;
extern GtkWidget *template_toolbar;

extern GList *last_list;
extern GtkWidget *last_menu;
extern gint last_document_value;

extern GtkWidget *undo_widget[2];
extern GtkWidget *redo_widget[2];
extern gint undo_max_value;

extern gint update_show;
extern gchar *update_url;

extern gchar *help_url;

extern gboolean automatic_extensions;

/* edit.c */
void editor_add (GtkWidget *, gpointer);
void editor_cut (GtkWidget *, gpointer);
void editor_copy (GtkWidget *, gpointer);
void editor_paste (GtkWidget *, gpointer);
void editor_delete (GtkWidget *, gpointer);
void editor_cut_triple (GtkWidget *, gpointer);
void editor_copy_triple (GtkWidget *, gpointer);
void editor_delete_triple (GtkWidget *, gpointer);
struct rdf_t *editor_triple (struct rdf_t *prev, gchar * title);
void editor_merge_file (GtkWidget *, gpointer);
void editor_merge_uri (GtkWidget *, gpointer);

/* file.c */
gboolean editor_open_file (gchar *, gchar *);
gboolean editor_open_uri (gchar *);
void editor_open (GtkWidget *, gpointer);
void editor_save_as (GtkWidget *, gpointer);
void editor_save (GtkWidget *, gpointer);
void editor_close (GtkWidget *, gpointer);
void editor_new (GtkWidget *, gpointer);
gchar *editor_tmp_file (void);

/* main.c */
int editor_quit (GtkWidget *, GdkEvent *, gpointer);
gchar *utf8 (gchar * str);
char *markup (gchar * str);
void statusbar_set (gchar * what, ...);
void fatal (gchar * text, ...);
void run (gchar ** a, GChildWatchFunc, gpointer);
GList *split (gchar * ar);

/* maker.c */
struct editor_data_t *editor_get_data (void);
gint editor_timeout (gpointer);
void editor_new_maker (struct editor_data_t *data);
void editor_refresh (struct editor_data_t *);
void editor_refresh_nslist (struct editor_data_t *);
gint editor_compare (struct rdf_t *, struct rdf_t *, struct editor_data_t *);
gint editor_nscompare (struct namespace_t *, struct namespace_t *,
		       struct editor_data_t *);

/* edit.c */
void editor_view (GtkWidget *, gpointer);
void editor_your_view (GtkWidget *, gpointer);
void editor_preferences (GtkWidget *, gpointer);
GList * create_no_dup (GList * ret);
GList *create_resources (struct editor_data_t *data);
GList *create_resources_by_rdfs (GList * ret);
GList *create_blank (struct editor_data_t *data);
void search_resources (GtkWidget * widget, GtkWidget * entry);

/* dialog.c */
void dialog_msg (gchar *);
void dialog_msg_with_error (gchar *, gchar *);
int dialog_ask (gchar *);
int dialog_ask_with_cancel (gchar *);
GtkWidget *dialog_wait (GCallback callback, gpointer data, GtkWidget ** pb);

/* filechooser.c */
void *file_chooser (gchar *, GtkSelectionMode, GtkFileChooserAction, enum rdf_format_t *);
gchar *uri_chooser (gchar *);

/* rdf.c */
GList *rdf_parse (gchar *, gboolean, enum rdf_format_t *, GString **);
gboolean rdf_parse_thread (gchar * resource, GList ** list, GList ** nslist,
			   gboolean this_document, enum rdf_format_t *,
			   GString **);
int rdf_save_file (gchar *, GList *, GList **, enum rdf_format_t);
int rdf_is_no_saved (struct editor_data_t *data);
void rdf_free (struct rdf_t *);
struct rdf_t *rdf_copy (struct rdf_t *);
gboolean rdf_blank (GList * rdf, gchar * t);
gboolean rdf_resource (GList * rdf, gchar * t);

/* namespace.c */
GList *namespace_parse (GList * rdf);
void namespace_free (struct namespace_t *);
gboolean namespace_visible (GList * ns, struct rdf_t *rdf);
gchar *namespace_prefix (GList ** ns, gchar * t);
gchar *namespace_create (GList *, gchar * t);

/* browser.c */
void browser (gchar *);
void browser_website (void);

/* init.c */
void init (void);
void init_save (void);

/* rdfs.c */
void rdfs (GtkWidget * w, gpointer dummy);
gint rdfs_add (gchar * resource, gchar * prefix);
gchar *rdfs_file (void);

/* graph.c */
void graph_run (GtkWidget * w, gpointer dummy);
void graph (struct editor_data_t *);
void graph_save (GtkWidget * w, gpointer dummy);
void graph_graphviz (void);

/* about.c */
void about (GtkWidget * w, gpointer dummy);

/* template.c */
void template_update (void);
void template_import_uri (GtkWidget * w, gpointer dummy);
void template_import_file (GtkWidget * w, gpointer dummy);
void template (GtkWidget * w, gpointer dummy);
gboolean template_import (gchar * uri, gboolean, gboolean);
void template_save (void);
void template_open (GtkWidget * w, struct template_t *t);
void template_edit (GtkWidget * w, struct template_t *t);

/* preferences.c */
void preferences (void);

/* splash.c */
void splash_show (void);
void splash_hide (void);
gboolean splash_showed (void);
void splash_set_text (char *, ...);
void splash_set_text_with_effect (char *, ...);
void splash_sleep (int);
void splash_close_on_click (gboolean value);

/* unredo.c */
struct unredo_t *unredo_new (struct editor_data_t *, enum unredo_type_t);
void unredo_add (struct unredo_t *unredo, struct rdf_t *rdf, struct rdf_t *);
void unredo_destroy (struct editor_data_t *, struct unredo_t *);
void unredo_undo (void);
void unredo_redo (void);
void unredo_change_value (void);

/* update.c */
gint update_timer (void);
void update_search (void);
gint update_check (void);

/* merge.c */
GList *merge (GList * rdf, gchar * what, GString **);
void merge_graph (void);

/* navigator.c */
void navigator_run (void);
void navigator_open_uri (void);

/* search.c */
gboolean search (gchar * uri, GList ** meta, GList ** other, gchar ** error);
void search_open (gchar * text, void (*func) (gchar *, gpointer), gpointer);

/* last.c */
void last_update (void);
void last_add (gchar * uri);
void last_change_value (void);

/* help.c */
void help (void);

/* info.c */
void info_selected(void);
void info_uri(void);
void info_this(void);
gboolean info_box_popup_show(GtkWidget *, GdkEventButton *, GList *);
gboolean info_box_popup_hide(GtkWidget *, GdkEventButton *, gpointer);
gboolean info_box_enter (GtkWidget *, GdkEventCrossing * , gpointer);
gboolean info_box_leave (GtkWidget *, GdkEventCrossing *, gpointer);
void info_box_free(struct info_box_t *);

/* EOF */
